package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: May 26, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
var (
Version = "dev"
Commit = "none"
BuiltAt = "unknown"
)
type Info struct {
Version string `json:"version"`
Commit string `json:"commit"`
BuiltAt string `json:"built_at"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.