Documentation
¶
Index ¶
- Constants
- Variables
- type Checker
- type Deleter
- type FileStore
- func (s *FileStore) Delete(_ context.Context, key string) error
- func (s *FileStore) Exists(_ context.Context, key string) (bool, error)
- func (s *FileStore) Get(_ context.Context, key string) ([]byte, error)
- func (s *FileStore) List(_ context.Context) ([]string, error)
- func (s *FileStore) Name() string
- func (s *FileStore) Put(_ context.Context, req PutRequest) (PutResult, error)
- func (s *FileStore) Status() Status
- type Getter
- type Lister
- type MemoryStore
- func (s *MemoryStore) Delete(_ context.Context, key string) error
- func (s *MemoryStore) Exists(_ context.Context, key string) (bool, error)
- func (s *MemoryStore) Get(_ context.Context, key string) ([]byte, error)
- func (s *MemoryStore) List(_ context.Context) ([]string, error)
- func (s *MemoryStore) Name() string
- func (s *MemoryStore) Put(_ context.Context, req PutRequest) (PutResult, error)
- func (s *MemoryStore) Status() Status
- type NoopStore
- type Object
- type PutRequest
- type PutResult
- type Putter
- type S3CompatibleConfig
- type S3CompatibleStore
- func (s *S3CompatibleStore) Delete(ctx context.Context, key string) error
- func (s *S3CompatibleStore) Exists(ctx context.Context, key string) (bool, error)
- func (s *S3CompatibleStore) Get(ctx context.Context, key string) ([]byte, error)
- func (s *S3CompatibleStore) Name() string
- func (s *S3CompatibleStore) Put(ctx context.Context, req PutRequest) (PutResult, error)
- func (s *S3CompatibleStore) Status() Status
- type Status
- type Store
Constants ¶
const ( BackendMemory = "memory" BackendFilesystem = "filesystem" BackendS3 = "s3" )
Variables ¶
var ErrInvalidInput = errors.New("invalid blob input")
var ErrNotFound = errors.New("blob not found")
Functions ¶
This section is empty.
Types ¶
type FileStore ¶
type FileStore struct {
// contains filtered or unexported fields
}
func NewFileStore ¶
func (*FileStore) List ¶
List returns the flat checksum keys currently present in the filesystem backend, giving migration tooling a safe way to report orphan candidates.
type Lister ¶
Lister is an optional safe inventory capability for local/provider adapters that can enumerate checksum keys without mutating blob contents.
type MemoryStore ¶
type MemoryStore struct {
// contains filtered or unexported fields
}
func NewMemoryStore ¶
func NewMemoryStore(target string) *MemoryStore
func (*MemoryStore) List ¶
func (s *MemoryStore) List(_ context.Context) ([]string, error)
List returns the in-memory checksum keys for local migration tests and memory-backed development runs without exposing mutable object internals.
func (*MemoryStore) Name ¶
func (s *MemoryStore) Name() string
func (*MemoryStore) Put ¶
func (s *MemoryStore) Put(_ context.Context, req PutRequest) (PutResult, error)
func (*MemoryStore) Status ¶
func (s *MemoryStore) Status() Status
type NoopStore ¶
type NoopStore struct {
// contains filtered or unexported fields
}
func NewNoopStore ¶
type PutRequest ¶
type S3CompatibleConfig ¶
type S3CompatibleConfig struct {
StorageURL string
Endpoint string
Region string
ForcePathStyle bool
DisableTLS bool
AccessKeyID string
SecretKey string
SessionToken string
RequestTimeout time.Duration
MaxRetries int
HTTPClient *http.Client
Now func() time.Time
Sleep func(context.Context, time.Duration) error
}
type S3CompatibleStore ¶
type S3CompatibleStore struct {
// contains filtered or unexported fields
}
func NewS3CompatibleStore ¶
func NewS3CompatibleStore(cfg S3CompatibleConfig) (*S3CompatibleStore, error)
func (*S3CompatibleStore) Delete ¶
func (s *S3CompatibleStore) Delete(ctx context.Context, key string) error
func (*S3CompatibleStore) Name ¶
func (s *S3CompatibleStore) Name() string
func (*S3CompatibleStore) Put ¶
func (s *S3CompatibleStore) Put(ctx context.Context, req PutRequest) (PutResult, error)
func (*S3CompatibleStore) Status ¶
func (s *S3CompatibleStore) Status() Status
Click to show internal directories.
Click to hide internal directories.